# Pull Request Template

## Description

Summary of the change and which issue it fixes.

Fixes # (issue)

## Type of change

Please delete options that are not relevant.

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (will cause existing functionality to not work as expected)
- [ ] This change requires a documentation update
- [ ] Documentation update

## How has this been tested?

Please describe the tests that you ran to verify your changes. Provide instructions 
so that the tests can be reproduced.

**Test Configuration**:

* OS:
* Python version:
* ...

## Checklist:

- [ ] I have made corresponding changes to the documentation
- [ ] I have added corresponding unit tests
- [ ] I have run ``doit`` and all tasks have passed
